@@ -30,19 +30,23 @@
 #' withr::with_options(
 #'   list(styler.cache_name = NULL), # temporarily deactivate cache
 #'   {
-#' transformers <- tidyverse_style()
-#' pd_nested <- styler:::compute_parse_data_nested(c(
-#'   "call(",
-#'   "  ab = 1,",
-#'   "  a  = 2",
-#'   ")"
-#' )) %>%
-#'   styler:::post_visit(transformers$initialize)
-#' nest <- pd_nested$child[[1]]
-#' styler:::token_is_on_aligned_line(nest)
-#' })
+#'     transformers <- tidyverse_style()
+#'     pd_nested <- styler:::compute_parse_data_nested(c(
+#'       "call(",
+#'       "  ab = 1,",
+#'       "  a  = 2",
+#'       ")"
+#'     )) %>%
+#'       styler:::post_visit(transformers$initialize)
+#'     nest <- pd_nested$child[[1]]
+#'     styler:::token_is_on_aligned_line(nest)
+#'   }
+#' )
 token_is_on_aligned_line <- function(pd_flat) {
-  line_idx <- 1 + cumsum(pd_flat$lag_newlines)
+  line_idx <- 1L + cumsum(pd_flat$lag_newlines)
+  # cannot use lag_newlines anymore since we removed tokens
+  # pos_id too expensive to construct in alignment_ensure_trailing_comma()
+  pd_flat$lag_newlines <- pd_flat$pos_id <- NULL
   pd_flat$.lag_spaces <- lag(pd_flat$spaces)
   pd_by_line <- split(pd_flat, line_idx)
   last_line_is_closing_brace_only <- nrow(last(pd_by_line)) == 1
@@ -76,7 +80,7 @@ token_is_on_aligned_line <- function(pd_flat) {
   if (any(starting_with_comma)) {
     return(FALSE)
   }
-  pd_is_multi_line <- map_lgl(pd_by_line, ~ any(.x$multi_line, na.rm = TRUE))
+  pd_is_multi_line <- map_lgl(pd_by_line, ~ any(.x$multi_line > 0L, na.rm = TRUE))
   if (any(pd_is_multi_line)) {
     return(FALSE)
   }
@@ -86,27 +90,66 @@ token_is_on_aligned_line <- function(pd_flat) {
     alignment_ensure_trailing_comma()
   # now, pd only contains arguments separated by values, ideal for iterating
   # over columns.
-  # cannot use lag_newlines anymore since we removed tokens.
-  pd_by_line <- map(pd_by_line, function(pd_sub) {
-    pd_sub$lag_newlines <- NULL
-    pd_sub
-  })
 
   n_cols <- map_int(pd_by_line, ~ sum(.x$token == "','"))
-  start <- ifelse(all(alignment_col1_is_named(pd_by_line)), 1, 2)
-
-  for (column in seq2(start, max(n_cols))) {
-    char_len <- alignment_serialize_column(pd_by_line, column) %>%
+  previous_line <- 0
+  start_eval <- ifelse(alignment_col1_all_named(pd_by_line), 1, 2)
+  for (column in seq2(1, max(n_cols))) {
+    by_line <- alignment_serialize_column(pd_by_line, column) %>%
       compact() %>%
       unlist() %>%
-      trimws(which = "right") %>%
-      nchar()
-
-    is_aligned <- length(unique(char_len)) == 1
-
-    if (!is_aligned) {
-      return(FALSE)
+      trimws(which = "right")
+    # check 1: match by comma
+    # might have fewer lines in subsequent columns.
+    current_col <- nchar(by_line)
+    if (column > 1) {
+      previous_line <- previous_line[intersect(names(previous_line), names(by_line))]
+      # must add previous columns, as first column might not align
+      current_col <- current_col + previous_line
     }
+
+    is_aligned <- length(unique(current_col)) == 1L
+    if (!is_aligned) {
+      # check 2: left aligned after ,
+      current_col <- nchar(gsub("^(,[\\s\\t]*)[^ ]*.*$", "\\1", by_line, perl = TRUE))
+
+      if (column > 1) {
+        # must add previous columns, as first column might not align
+        current_col <- current_col + previous_line
+      }
+      is_aligned <- length(unique(current_col)) == 1L
+      if (is_aligned) {
+        # if left aligned after ,
+        start_eval <- 2
+      }
+    }
+    if (is_aligned) {
+      previous_line <- previous_line + nchar(by_line)
+      next
+    }
+    # check 3: match by = (no extra spaces around it allowed.)
+    # match left aligned after =
+    start_after_eq <- regexpr("= [^ ]", by_line)
+    names(start_after_eq) <- names(by_line)
+    start_after_eq <- start_after_eq[start_after_eq > 0]
+
+    if (column >= start_eval) {
+      if (length(start_after_eq) == 0) {
+        return(FALSE)
+      }
+      # when match via comma unsuccessful, matching by = must yield at least one =
+      if (column == 1) {
+        current_col <- start_after_eq
+      } else {
+        current_col <- start_after_eq +
+          previous_line[intersect(names(previous_line), names(start_after_eq))]
+      }
+      is_aligned <- length(unique(current_col)) == 1 && length(start_after_eq) > 1
+      if (!is_aligned) {
+        return(FALSE)
+      }
+    }
+    previous_line <- nchar(by_line) + previous_line
   }
   TRUE
 }
