@@ -7,7 +7,7 @@
 #' @importFrom purrr when
 #' @keywords internal
 create_tree <- function(text, structure_only = FALSE) {
-  compute_parse_data_nested(text) %>%
+  compute_parse_data_nested(text, transformers = NULL) %>%
     pre_visit(c(default_style_guide_attributes)) %>%
     create_tree_from_pd_with_default_style_attributes(structure_only)
 }
@@ -30,11 +30,15 @@ create_tree_from_pd_with_default_style_attributes <- function(pd, structure_only
 #' @return An object of class "Node" and "R6".
 #' @examples
 #' if (rlang::is_installed("data.tree")) {
-#'   cache_deactivate() # keep things simple
-#'   code <- "a <- function(x) { if(x > 1) { 1+1 } else {x} }"
-#'   nested_pd <- styler:::compute_parse_data_nested(code)
-#'   initialized <- styler:::pre_visit(nested_pd, c(default_style_guide_attributes))
-#'   styler:::create_node_from_nested_root(initialized, structure_only = FALSE)
+#'   withr::with_options(
+#'     list(styler.cache_name = NULL), # temporarily deactivate cache
+#'     {
+#'       code <- "a <- function(x) { if(x > 1) { 1+1 } else {x} }"
+#'       nested_pd <- styler:::compute_parse_data_nested(code)
+#'       initialized <- styler:::pre_visit(nested_pd, c(default_style_guide_attributes))
+#'       styler:::create_node_from_nested_root(initialized, structure_only = FALSE)
+#'     }
+#'   )
 #' }
 #' @keywords internal
 create_node_from_nested_root <- function(pd_nested, structure_only) {
