@@ -76,7 +76,7 @@ has_crlf_as_first_line_sep <- function(message, initial_text) {
 #' @keywords internal
 tokenize <- function(text) {
   get_parse_data(text, include_text = TRUE) %>%
-    ensure_correct_str_txt(text) %>%
+    ensure_correct_txt(text) %>%
     enhance_mapping_special()
 }
 
@@ -116,54 +116,57 @@ add_id_and_short <- function(pd) {
 }
 
 
-#' Ensure a correct `text` of all strings
+#' Ensure a correct `text` of all strings and numeric constants
 #'
-#' Make sure `text` of the tokens `STR_CONST` is correct and adapt if necessary.
-#' We first parse `text` again and include also non-terminal text. Then, we
-#' replace offending `text` in the terminal expressions with the text of their
-#' parents if their line / col position matches and return an error otherwise.
+#' Make sure `text` of the tokens `STR_CONST` and `NUM_CONST` is correct and
+#' adapt if necessary. We replace offending `text` in the terminal expressions
+#' with the text of their parents if their line / col position matches and
+#' return an error otherwise.
 #' @param pd A parse table.
-#' @param text The text from which `pd` was created. Needed potentially
-#'   for another round of parsing.
 #' @importFrom rlang abort
+#' @importFrom magrittr or
 #' @keywords internal
-ensure_correct_str_txt <- function(pd, text) {
+ensure_correct_txt <- function(pd, text) {
   ensure_valid_pd(pd)
-  is_problematic_string <- identify_insufficiently_parsed_strings(pd, text)
-  problematic_strings <- pd[is_problematic_string, ]
-  is_parent_of_problematic_string <-
-    pd$id %in% problematic_strings$parent
-
-  is_unaffected_token <- !(is_problematic_string | is_parent_of_problematic_string)
-  if (!any(is_problematic_string)) {
+  is_problematic_text <- or(
+    is_insufficiently_parsed_string(pd),
+    is_insufficiently_parsed_number(pd)
+  )
+  if (!any(is_problematic_text)) {
     return(pd)
   }
+  problematic_text <- pd[is_problematic_text, ]
+  is_parent_of_problematic_string <- pd$id %in% problematic_text$parent
+
+  is_unaffected_token <- !or(
+    is_problematic_text, is_parent_of_problematic_string
+  )
 
   pd_with_all_text <- get_parse_data(text, include_text = TRUE)
   parent_cols_for_merge <- c("id", "text", "short", line_col_names())
-  parent_of_problematic_strings <-
+  parent_of_problematic_text <-
     pd_with_all_text[is_parent_of_problematic_string, parent_cols_for_merge]
-  problematic_strings$text <- NULL
-  problematic_strings$short <- NULL
-  new_strings <- merge(problematic_strings, parent_of_problematic_strings,
+  problematic_text$text <- NULL
+  problematic_text$short <- NULL
+  new_text <- merge(problematic_text, parent_of_problematic_text,
     by.x = "parent",
     by.y = "id",
     suffixes = c("", "parent")
   ) %>%
     as_tibble(.name_repair = "minimal")
 
-  if (!lines_and_cols_match(new_strings)) {
+  if (!lines_and_cols_match(new_text)) {
     abort(paste(
-      "Error in styler:::ensure_correct_str_txt().",
-      "Please file an issue on GitHub (https://github.com/r-lib/styler/issues)",
+      "Error in styler:::ensure_correct_txt().",
+      "Please file an issue on GitHub (https://github.com/r-lib/styler/issues)"
     ))
   }
   names_to_keep <- setdiff(
-    names(new_strings),
+    names(new_text),
     paste0(line_col_names(), "parent")
   )
   bind_rows(
-    new_strings[, names_to_keep],
+    new_text[, names_to_keep],
     pd[is_unaffected_token, ],
     pd[is_parent_of_problematic_string, ]
   ) %>%
@@ -205,15 +208,13 @@ ensure_valid_pd <- function(pd) {
 #' @param pd A parse table.
 #' @param text The initial code to style.
 #' @keywords internal
-identify_insufficiently_parsed_strings <- function(pd, text) {
-  is_problematic_string <- pd$token == "STR_CONST"
-  candidate_substring <- substr(
-    pd$text[is_problematic_string], 1, 1
-  )
-  is_problematic_string[is_problematic_string] <- candidate_substring == "["
-  is_problematic_string
+is_insufficiently_parsed_string <- function(pd) {
+  grepl("^\\[", pd$text) & pd$token == "STR_CONST"
 }
 
+is_insufficiently_parsed_number <- function(pd) {
+  grepl("^0x", pd$text) & pd$token == "NUM_CONST"
+}
 #' @importFrom purrr map2_lgl
 lines_and_cols_match <- function(data) {
   left <- paste0(line_col_names(), "")
