@@ -26,13 +26,13 @@
 #' @keywords internal
 create_tokens <- function(tokens,
                           texts,
-                          lag_newlines = 0,
-                          spaces = 0,
+                          lag_newlines = 0L,
+                          spaces = 0L,
                           pos_ids,
                           token_before = NA,
                           token_after = NA,
                           indention_ref_pos_ids = NA,
-                          indents = 0,
+                          indents = 0L,
                           terminal = TRUE,
                           child = NULL,
                           stylerignore = FALSE,
@@ -52,7 +52,7 @@ create_tokens <- function(tokens,
       terminal = rep(terminal, len_text),
       internal = rep(FALSE, len_text),
       spaces = spaces,
-      multi_line = rep(FALSE, len_text),
+      multi_line = rep(0L, len_text),
       indention_ref_pos_id = indention_ref_pos_ids,
       indent = indents,
       child = rep(list(child), len_text),
